==> haskell-tasty-expected-failure-0.11.0.4-10-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-expected-failure
version: 0.11.0.4
id: tasty-expected-failure-0.11.0.4-D5tAZPCL0LP1DK72RG8gAj
key: tasty-expected-failure-0.11.0.4-D5tAZPCL0LP1DK72RG8gAj
license: MIT
copyright: 2015 Joachim Breitner
maintainer: mail@joachim-breitner.de
homepage: http://github.com/nomeata/tasty-expected-failure
synopsis: Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.
    .
    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.
    .
    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.
    .
    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.
category: Testing
author: Joachim Breitner
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.ExpectedFailure
abi: 1cbd27a9c568559060200366704a8ac4
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-expected-failure-0.11.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-expected-failure-0.11.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-expected-failure-0.11.0.4
hs-libraries: HStasty-expected-failure-0.11.0.4-D5tAZPCL0LP1DK72RG8gAj
depends:
    base-4.10.1.0 tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    tasty-1.0.1-AWWNaFTEpDABJ6I60QHIFP
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             tasty-1.0.1-AWWNaFTEpDABJ6I60QHIFP=676bfe39e5968a7e880bebc46f35c0bf
haddock-interfaces: /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock
haddock-html: /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tasty-expected-failure-0.11.0.4-13-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-tasty-expected-failure.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: tasty-expected-failure
version: 0.11.0.4
id: tasty-expected-failure-0.11.0.4-1PMh8LDA3CiFDx1Gxw6SfJ
key: tasty-expected-failure-0.11.0.4-1PMh8LDA3CiFDx1Gxw6SfJ
license: MIT
copyright: 2015 Joachim Breitner
maintainer: mail@joachim-breitner.de
homepage: http://github.com/nomeata/tasty-expected-failure
synopsis: Mark tasty tests as failure expected
description:
    With the function '\''Test.Tasty.ExpectedFailure.expectFail'\'' in the provided module
    "Test.Tasty.ExpectedFailure", you can mark that you expect test cases to fail,
    and not to pass.
    .
    This can for example be used for test-driven development: Create the tests,
    mark them with '\''Test.Tasty.ExpectedFailure.expectFail'\'', and you can still push
    to the main branch, without your continuous integration branch failing.
    .
    Once someone implements the feature or fixes the bug (maybe unknowingly), the
    test suite will tell him so, due to the now unexpectedly passing test, and he
    can remove the '\''Test.Tasty.ExpectedFailure.expectFail'\'' marker.
    .
    The module also provides '\''Test.Tasty.ExpectedFailure.ignoreTest'\'' to avoid
    running a test. Both funtions are implemented via the more general
    '\''Test.Tasty.ExpectedFailure.wrapTest'\'', which is also provided.
category: Testing
author: Joachim Breitner
exposed: True
indefinite: False
exposed-modules:
    Test.Tasty.ExpectedFailure
abi: d0471ea376fb6f91c47155b9b292b8d0
trusted: False
import-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-expected-failure-0.11.0.4
library-dirs: /usr/lib/ghc-8.2.2/site-local/tasty-expected-failure-0.11.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/arm-linux-ghc-8.2.2/tasty-expected-failure-0.11.0.4
hs-libraries: HStasty-expected-failure-0.11.0.4-1PMh8LDA3CiFDx1Gxw6SfJ
depends:
    base-4.10.1.0 tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2
    tasty-1.0.1-K2rsmdQu5cZEc4jR5Y73ik
abi-depends: base-4.10.1.0=0ea45191c57c268b2351cb731ab6a0d6
             tagged-0.8.5-BP06XmR1GLaIsvsOKwGst2=b5d07becd47ba21e20b584b61ad0f06d
             tasty-1.0.1-K2rsmdQu5cZEc4jR5Y73ik=ebb3680bb17064f549df9640b7cd1369
haddock-interfaces: /usr/share/doc/haskell-tasty-expected-failure/html/tasty-expected-failure.haddock
haddock-html: /usr/share/doc/haskell-tasty-expected-failure/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
